##
## AddIn0.py - More lines...
##
"""AddIn sample 0: Line creation and transformation sample.

This sample series (0-3) of python scripts introduces the way CADdy++ 
AddIns should be written.

An 'AddIn' is a kind of plugin. Actually, it is a registered COM server which 
provides arbitrarily services, which may be meaningful for the CADdy++ user. 

Registration of the AddIn can be performed by just running this script
from the command shell.

Starting of the AddIn0 will be performed by running of the associated 
script RunAddIn0.py.

Sample AddIn0 shows the most simple usage pattern of the CADdy++ AddIn framework.
On exectuting the AddIn, function OnInit() is called with the application object
as the only function parameter. The AddIn0 implements the 'Hello Wolrd' example.
"""
from CADdy.AddInServer import *

class AddIn0(AddInBase):
    """AddIn0 - Sample AddIn class.
    
    The following two characteristics must be provided on the definition of 
    an AddIn:
        _reg_clsid_  : A GUID string by which the AddIn is uniquely referenced.
                       The CADdy++ Python COM framework provides two convenience
                       methods for generating such a GUID string.
                       Firstly, from within the Python interactive interpreter,
                       and secondly from a DOS command shell.
                       1. The CADdy.AddInServer module provides a method Guid(),
                          which prints a new GUID string to the standard output.
                          Example:
                            >>> from CADdy.AddInServer import Guid
                            >>> Guid()
                            IID('{379F9FB4-5136-4245-982F-4406D5766F5E}')
                       2. From a DOS shell the modul AddInServer.py in folder
                          CADdy can be directly called. It just prints a newly
                          created GUID and returns.
                          Example:
                            > cd {CADdyInstallPath}\Program\Python\Lib\site-packages\CADdy
                            > AddInServer.py
                            {379F9FB4-5136-4245-982F-4406D5766F5E}
        _reg_progid_ : The name of the AddIn.
    """
    _reg_clsid_  = '{379F9FB4-5136-4245-982F-4406D5766F5E}'
    _reg_progid_ = 'CADdyAddIn.PythonAddIn0'

    def __init__(self):
        """Constructor - just call the base constructor."""
        AddInBase.__init__(self)

    def OnInit(self, theCADdy):
        """Main entry of the AddIn. 
        
        This function is called when the AddIn is invoked. The AddIn its functional 
        implementation goes here. For now we just show the 'Hello World' dialog 
        from Lesson 0. But later we will use this function call for establishing 
        CADdy++ command pools, commands and its handlers. 
        """
        uiManager = theCADdy.UIManager()
        uiManager.Information("Hello World!")
            
def main():
    """Main function - called on running the script from the command line.
    
    This function will register the AddIn in the Windows registry as an valid
    COM server.
    """
    RegisterServer(AddIn0)
    
if __name__ == '__main__':
    main()

