"""Variante1: Boden

Erzeugt die Geometrie fuer einen kreisfoermigen Boden mit Radius 'R', der in
Streifen der Breite 'b' aufgeteilt ist. Die Mitte ist in 'cx,cy'.
"""

import math
from CADdy.Application   import GetApplic
from CADdy.Utility.Model import AddToParent

cx, cy = 100.0, 200.0
R = 100.0
b = 35.0

theCADdy = GetApplic()

factory       = theCADdy.Factory2D()
targetManager = theCADdy.TargetManager()
typesManager  = theCADdy.DataTypesManager()

# Unterhalb der aktuellen Teilzeichnung werden fuer jede Blechkontur Gruppen
# angelegt. Dazu wird das aktuelle Sketchboard ermittelt.
target = targetManager.TargetOp2DSketchboard

# Zur Erstellung der Kreissegmente wird spaeter u.a. die Mittelposition benoetigt
center = typesManager.Create2DPosition(cx, cy)

# Die von links nach rechts sortierten Eckpunkte der
# Bleche kommen in eine Liste von je drei Punkten:
#       Die Schnittpunkte auf der Mittelachse.
#       die Schnittpunkt der Streifenkanten auf dem Kreis oben und unten
#       Das sind die Loesungen von (x-cx)**2 +(y-cy)**2 = R**2

# Die am weitesten links gelegene Position ist (cx-R, cy)
pos = typesManager.Create2DPosition(cx-R, cy)

positions =[]
positions.append( (pos, pos, pos) )

# Zuerst kommt ein Streifen mit der Restbreite R % b, dann Streifen der Breite b.
d = -R + (R % b)

while d < R:
    h = math.sqrt(R*R - d*d)
    
    posO = typesManager.Create2DPosition(cx+d, cy+h)
    posM = typesManager.Create2DPosition(cx+d, cy)
    posU = typesManager.Create2DPosition(cx+d, cy-h)
    positions.append( (posO, posM, posU) )
    d += b

# Die am weitesten rechts gelegene Position ist (cx+R, cy).
pos = typesManager.Create2DPosition(cx+R, cy)
positions.append( (pos, pos, pos) )


# Die Liste der vorgefertigten Positionen wird durchlaufen, um
# die Begrenzungslinien zu erzeugen.
posOL, posML, posUL = positions[0]; i = 0
for posOR, posMR, posUR in positions[1:]:
    i+=1
    groupO = factory.CreateOp2DGroup("Blech %d" % i)
    AddToParent(groupO,target)
    
    i+=1
    groupU = factory.CreateOp2DGroup("Blech %d" % i)
    AddToParent(groupU,target)

    basisO = factory.CreateOp2DStraSeg(posMR, posML)
    lineLO = factory.CreateOp2DStraSeg(posML, posOL)
    lineRO = factory.CreateOp2DStraSeg(posOR, posMR)

    basisU = factory.CreateOp2DStraSeg(posMR, posML)
    lineLU = factory.CreateOp2DStraSeg(posML, posUL)
    lineRU = factory.CreateOp2DStraSeg(posUR, posMR)

    vec1 = posOL.Difference(center)
    vec2 = posOR.Difference(center)

    angle1, len = vec1.GetPolar()
    angle2, len = vec2.GetPolar()

    diff = angle1.Difference(angle2)
    circleO = factory.CreateOp2DCirSeg(center, R, angle2, diff)
    
    angle2.Grad = -angle2.Grad
    diff.Grad   = -diff.Grad
    circleU = factory.CreateOp2DCirSeg(center, R, angle2, diff)

    AddToParent(lineLO,  groupO)
    AddToParent(circleO, groupO)
    AddToParent(lineRO,  groupO)
    AddToParent(basisO,  groupO)

    AddToParent(lineLU,  groupU)
    AddToParent(circleU, groupU)
    AddToParent(lineRU,  groupU)
    AddToParent(basisU,  groupU)

    posOL, posML, posUL = posOR, posMR, posUR
